@@ -49,33 +49,30 @@ struct DMRaid_Member
 class DMRaid
 {
 public:
-	DMRaid() ;
-	DMRaid( const bool & do_refresh ) ;
-	~DMRaid() ;
-	bool is_dmraid_supported() ;
-	bool is_dmraid_device( const Glib::ustring & dev_path ) ;
-	void get_devices( std::vector<Glib::ustring> & dmraid_devices ) ;
-	Glib::ustring get_dmraid_name( const Glib::ustring & dev_path ) ;
-	Glib::ustring make_path_dmraid_compatible( Glib::ustring partition_path ) ;
-	bool create_dev_map_entries( const Partition & partition, OperationDetail & operationdetail ) ;
-	bool create_dev_map_entries( const Glib::ustring & dev_path ) ;
-	bool delete_affected_dev_map_entries( const Partition & partition, OperationDetail & operationdetail ) ;
-	bool purge_dev_map_entries( const Glib::ustring & dev_path ) ;
-	bool update_dev_map_entry( const Partition & partition, OperationDetail & operationdetail ) ;
-	bool is_member(const Glib::ustring& member_path);
-	bool is_member_active(const Glib::ustring& member_path);
-	const Glib::ustring& get_array(const Glib::ustring& member_path);
+	static void load_cache();
+	static bool is_dmraid_supported();
+	static bool is_dmraid_device(const Glib::ustring& dev_path);
+	static std::vector<Glib::ustring> get_devices();
+	static Glib::ustring get_dmraid_name(const Glib::ustring& dev_path);
+	static Glib::ustring make_path_dmraid_compatible(Glib::ustring partition_path);
+	static bool create_dev_map_entries(const Partition& partition, OperationDetail& operationdetail);
+	static bool create_dev_map_entries(const Glib::ustring& dev_path);
+	static bool delete_affected_dev_map_entries(const Partition& partition, OperationDetail& operationdetail);
+	static bool purge_dev_map_entries(const Glib::ustring& dev_path);
+	static bool update_dev_map_entry(const Partition& partition, OperationDetail& operationdetail);
+	static bool is_member(const Glib::ustring& member_path);
+	static bool is_member_active(const Glib::ustring& member_path);
+	static const Glib::ustring& get_array(const Glib::ustring& member_path);
 
 private:
-	void load_dmraid_cache() ;
-	void set_commands_found() ;
-	int execute_command(const Glib::ustring& command, OperationDetail& operationdetail);
-	void get_dmraid_dir_entries( const Glib::ustring & dev_path, std::vector<Glib::ustring> & dir_list ) ;
-	int get_partition_number(const Glib::ustring& partition_name);
-	Glib::ustring get_udev_dm_name(const Glib::ustring& dev_path);
-	bool delete_dev_map_entry(const Partition& partition, OperationDetail& operationdetail);
-	void get_affected_dev_map_entries( const Partition & partition, std::vector<Glib::ustring> & affected_entries ) ;
-	void get_partition_dev_map_entries( const Partition & partition, std::vector<Glib::ustring> & partition_entries ) ;
+	static void load_dmraid_cache();
+	static void set_commands_found();
+	static std::vector<Glib::ustring> get_dmraid_dir_entries(const Glib::ustring& dev_path);
+	static int get_partition_number(const Glib::ustring& partition_name);
+	static Glib::ustring get_udev_dm_name(const Glib::ustring& dev_path);
+	static bool delete_dev_map_entry(const Partition& partition, OperationDetail& operationdetail);
+	static std::vector<Glib::ustring> get_affected_dev_map_entries(const Partition& partition);
+	static std::vector<Glib::ustring> get_partition_dev_map_entries(const Partition& partition);
 	static std::vector<Glib::ustring> lookup_dmraid_members(const Glib::ustring& array);
 	static const DMRaid_Member& get_cache_entry_by_member(const Glib::ustring& member_path);
 
@@ -87,6 +84,8 @@ private:
 	static std::vector<DMRaid_Member> dmraid_member_cache;
 };
 
-}//GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_DMRAID_H */
