@@ -27,13 +27,12 @@
 
 namespace GParted
 {
-	
+
+
 class Device
 {
-	 
 public:
 	Device() ;
-	~Device() ;
 
 	Device get_copy_without_partitions() const;
 	void set_path( const Glib::ustring & path );
@@ -66,7 +65,9 @@ private:
 	Glib::ustring path;
 	int max_partition_name_length;  // > 0 => naming of partitions is supported on this device
 };
- 
-} //GParted
+
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_DEVICE_H */
