@@ -24,24 +24,27 @@
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
 
+
 namespace GParted
 {
 
+
 class DialogPasswordEntry : public Gtk::Dialog
 {
 public:
 	DialogPasswordEntry(const Partition& partition, const Glib::ustring& reason);
-	~DialogPasswordEntry();
 	const char * get_password();
 	void set_error_message( const Glib::ustring & message );
 
 private:
 	void on_button_unlock();
 
-	Gtk::Entry *entry;
-	Gtk::Label *error_message;
+	Gtk::Entry *m_entry;
+	Gtk::Label *m_error_message;
 };
 
-} //GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTEDPASSWORDENTRY_H */
