@@ -18,18 +18,23 @@
 #ifndef GPARTED_DIALOG_PARTITION_NEW_H
 #define GPARTED_DIALOG_PARTITION_NEW_H
 
-#include "Dialog_Base_Partition.h"
+
 #include "Device.h"
+#include "Dialog_Base_Partition.h"
+#include "FileSystem.h"
 #include "OptionComboBox.h"
 #include "Partition.h"
 #include "Utils.h"
 
+#include <gtkmm/entry.h>
 #include <gtkmm/grid.h>
+#include <vector>
 
 
 namespace GParted
 {
 
+
 class Dialog_Partition_New : public Dialog_Base_Partition
 {
 public:
@@ -40,13 +45,12 @@ public:
 	                     const std::vector<FS> & FILESYSTEMS );
 	~Dialog_Partition_New();
 
-	const Partition & Get_New_Partition();
+	Dialog_Partition_New(const Dialog_Partition_New& src) = delete;             // Copy construction prohibited
+	Dialog_Partition_New& operator=(const Dialog_Partition_New& rhs) = delete;  // Copy assignment prohibited
+
+	const Partition& get_new_partition();
 
 private:
-	Dialog_Partition_New( const Dialog_Partition_New & src );              // Not implemented copy constructor
-	Dialog_Partition_New & operator=( const Dialog_Partition_New & rhs );  // Not implemented copy assignment operator
-
-
 	void set_data( const Device & device,
 	               const Partition & partition,
 	               bool any_extended,
@@ -62,13 +66,16 @@ private:
 	Gtk::Entry filesystem_label_entry;
 
 	std::vector<FS> FILESYSTEMS ;
-	
-	//signal handlers
-	void combobox_changed(bool);
 
-	unsigned short new_count, first_creatable_fs ;
+	//signal handlers
+	void combobox_changed(bool combo_type_changed);
+
+	unsigned short new_count;
+	int default_fs;
 };
 
-} //GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_DIALOG_PARTITION_NEW_H */
