@@ -31,9 +31,11 @@
 #include <glibmm/ustring.h>
 #include <vector>
 
+
 namespace GParted
 {
 
+
 struct LVM2_PV
 {
 	BlockSpecial  pv_name;
@@ -55,7 +57,7 @@ class LVM2_PV_Info
 public:
 	static bool is_lvm2_pv_supported();
 	static void clear_cache();
-	static Glib::ustring get_vg_name( const Glib::ustring & path );
+	static const Glib::ustring& get_vg_name(const Glib::ustring& path);
 	static Byte_Value get_size_bytes( const Glib::ustring & path );
 	static Byte_Value get_free_bytes( const Glib::ustring & path );
 	static bool has_active_lvs( const Glib::ustring & path );
@@ -69,7 +71,7 @@ private:
 	static void load_lvm2_pv_info_cache();
 	static const LVM2_PV & get_pv_cache_entry_by_name( const Glib::ustring & pvname );
 	static const LVM2_VG & get_vg_cache_entry_by_name( const Glib::ustring & vgname );
-	static Byte_Value lvm2_pv_size_to_num( const Glib::ustring str ) ;
+	static Byte_Value lvm2_pv_size_to_num(const Glib::ustring& str);
 	static bool bit_set( const Glib::ustring & attr, unsigned int bit ) ;
 	static bool lvm2_pv_info_cache_initialized ;
 	static bool lvm_found ;
@@ -78,6 +80,8 @@ private:
 	static std::vector<Glib::ustring> error_messages ;
 };
 
-}//GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_LVM2_PV_INFO_H */
