@@ -18,17 +18,22 @@
 #ifndef GPARTED_OPERATIONDETAIL_H
 #define GPARTED_OPERATIONDETAIL_H
 
+
 #include "ProgressBar.h"
 
 #include <glibmm/ustring.h>
 #include <glibmm/markup.h>
-
+#include <sigc++/connection.h>
+#include <sigc++/signal.h>
+#include <sigc++/slot.h>
 #include <vector>
 #include <ctime>
 
+
 namespace GParted
 {
 
+
 enum OperationDetailStatus {
 	STATUS_NONE    = 0,
 	STATUS_EXECUTE = 1,
@@ -38,13 +43,43 @@ enum OperationDetailStatus {
 	STATUS_WARNING = 5
 };
 
+
 enum Font {
-	FONT_NORMAL	 = 0,
-	FONT_BOLD	 = 1,
-	FONT_ITALIC	 = 2,
-	FONT_BOLD_ITALIC = 3
+	FONT_NORMAL      = 0,
+	FONT_BOLD        = 1,
+	FONT_ITALIC      = 2,
+	FONT_BOLD_ITALIC = 3,
+	FONT_MONOSPACE   = 4
 } ;
 
+
+enum ExecFlags
+{
+	EXEC_NONE            = 1 << 0,
+	EXEC_CHECK_STATUS    = 1 << 1,  // Set the status of the command in the operation
+	                                // details based on the exit status being zero or
+	                                // non-zero.  Must either use this flag when calling
+	                                // ::execute_command() or manually call
+					// ::set_success_and_capture_errors() afterwards.
+	EXEC_CANCEL_SAFE     = 1 << 2,
+	EXEC_PROGRESS_STDOUT = 1 << 3,  // Run progress tracking callback after reading new
+	                                // data on stdout from command.
+	EXEC_PROGRESS_STDERR = 1 << 4,  // Same but for stderr.
+	EXEC_PROGRESS_TIMED  = 1 << 5   // Run progress tracking callback periodically.
+};
+
+inline ExecFlags operator|(ExecFlags lhs, ExecFlags rhs)
+	{ return static_cast<ExecFlags>(static_cast<unsigned>(lhs) | static_cast<unsigned>(rhs)); }
+
+inline ExecFlags operator&(ExecFlags lhs, ExecFlags rhs)
+	{ return static_cast<ExecFlags>(static_cast<unsigned>(lhs) & static_cast<unsigned>(rhs)); }
+
+
+class OperationDetail;
+typedef sigc::slot<void, OperationDetail*> StreamSlot;
+typedef sigc::slot<bool, OperationDetail*> TimedSlot;
+
+
 class OperationDetail
 {
 
@@ -67,12 +102,19 @@ public:
 	Glib::ustring get_elapsed_time() const ;
 	
 	void add_child( const OperationDetail & operationdetail ) ;
-	std::vector<OperationDetail*> & get_childs() ;
-	const std::vector<OperationDetail*> & get_childs() const ;
+	std::vector<OperationDetail*>& get_children();
+	const std::vector<OperationDetail*>& get_children() const;
 	OperationDetail & get_last_child() ;
-	void run_progressbar( double progress, double target, ProgressBar_Text text_mode = PROGRESSBAR_TEXT_NONE );
+	void run_progressbar(double progress, double target, ProgressBar_Text text_mode = PROGRESSBAR_TEXT_TIME_REMAINING);
 	void stop_progressbar();
 
+	int execute_command(const Glib::ustring& command, ExecFlags flags = EXEC_NONE);
+	int execute_command(const Glib::ustring& command, const char* input, ExecFlags flags = EXEC_NONE);
+	int execute_command(const Glib::ustring& command, ExecFlags flags, StreamSlot stream_progress_slot);
+	int execute_command(const Glib::ustring& command, ExecFlags flags, TimedSlot timed_progress_slot);
+	static const Glib::ustring& get_command_output();
+	static const Glib::ustring& get_command_error();
+
 	sigc::signal< void, const OperationDetail & > signal_update ;
 	sigc::signal< void, bool > signal_cancel;
 	sigc::signal< void, OperationDetail &, bool > signal_capture_errors;
@@ -82,7 +124,11 @@ private:
 	void add_child_implement( const OperationDetail & operationdetail );
 	void on_update( const OperationDetail & operationdetail ) ;
 	void cancel( bool force );
-	ProgressBar & get_progressbar() const;
+	const ProgressBar& get_progressbar() const;
+
+	int execute_command_internal(const Glib::ustring& command, const char* input, ExecFlags flags,
+	                             StreamSlot stream_progress_slot,
+	                             TimedSlot timed_progress_slot);
 
 	Glib::ustring description ;
 	OperationDetailStatus status ; 
@@ -97,6 +143,8 @@ private:
 	sigc::connection cancelconnection;
 };
 
-} //GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_OPERATIONDETAIL_H */
