@@ -23,9 +23,11 @@
 #include "BlockSpecial.h"
 #include "Partition.h"
 
+
 namespace GParted
 {
 
+
 struct BTRFS_Device
 {
 	int                       devid;
@@ -55,6 +57,7 @@ private:
 };
 
 
-} //GParted
+}  // namespace GParted
+
 
 #endif /* GPARTED_BTRFS_H */
