@@ -19,12 +19,14 @@
 #ifndef GPARTED_HFSPLUS_H
 #define GPARTED_HFSPLUS_H
 
-#include "../include/FileSystem.h"
-#include "../include/Partition.h"
+#include "FileSystem.h"
+#include "Partition.h"
+
 
 namespace GParted
 {
 
+
 class hfsplus : public FileSystem
 {
 public:
@@ -33,6 +35,8 @@ public:
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 };
 
-} //GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_HFSPLUS_H */
