@@ -22,9 +22,11 @@
 #include "OperationDetail.h"
 #include "Partition.h"
 
+
 namespace GParted
 {
 
+
 class minix : public FileSystem
 {
 public:
@@ -33,6 +35,8 @@ public:
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail );
 };
 
-} //GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_MINIX_H */
