@@ -22,9 +22,11 @@
 #include "FileSystem.h"
 #include "Partition.h"
 
+
 namespace GParted
 {
 
+
 class reiser4 : public FileSystem
 {
 public:
@@ -36,6 +38,8 @@ public:
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 };
 
-} //GParted
+
+}  // namespace GParted
+
 
 #endif /* GPARTED_REISER4_H */
