@@ -15,46 +15,46 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #include "OperationResizeMove.h"
+
+#include "Device.h"
+#include "Operation.h"
 #include "Partition.h"
 #include "PartitionVector.h"
+#include "Utils.h"
+
+#include <glib.h>
+#include <glibmm/ustring.h>
+
 
 namespace GParted
 {
 
+
 OperationResizeMove::OperationResizeMove( const Device & device,
 				  	  const Partition & partition_orig,
 				  	  const Partition & partition_new )
+ : Operation(OPERATION_RESIZE_MOVE, device, partition_orig, partition_new)
 {
-	type = OPERATION_RESIZE_MOVE ;
-
-	this->device = device.get_copy_without_partitions();
-	this->partition_original = partition_orig.clone();
-	this->partition_new      = partition_new.clone();
 }
 
-OperationResizeMove::~OperationResizeMove()
-{
-	delete partition_original;
-	delete partition_new;
-	partition_original = NULL;
-	partition_new = NULL;
-}
 
 void OperationResizeMove::apply_to_visual( PartitionVector & partitions )
 {
-	g_assert( partition_original != NULL );  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_original != nullptr);  // Bug: Not initialised by constructor or reset later
 
-	if ( partition_original->type == TYPE_EXTENDED )
+	if (m_partition_original->type == TYPE_EXTENDED)
 		apply_extended_to_visual( partitions ) ;
 	else 
 		apply_normal_to_visual( partitions ) ;
 }
 
+
 void OperationResizeMove::create_description() 
 {
-	g_assert( partition_original != NULL );  // Bug: Not initialised by constructor or reset later
-	g_assert( partition_new != NULL );  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_original != nullptr);  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_new != nullptr);  // Bug: Not initialised by constructor or reset later
 
 	//i'm not too happy with this, but i think it is the correct way from a i18n POV
 	enum Action
@@ -71,85 +71,88 @@ void OperationResizeMove::create_description()
 	} ;
 	Action action = NONE ;
 
-	if ( partition_new->get_sector_length() > partition_original->get_sector_length() )
+	if (m_partition_new->get_sector_length() > m_partition_original->get_sector_length())
 	{
 		//Grow partition
 		action = GROW ;
-		if ( partition_new->sector_start > partition_original->sector_start )
+		if (m_partition_new->sector_start > m_partition_original->sector_start)
 			action = MOVE_RIGHT_GROW ;
-		if ( partition_new->sector_start < partition_original->sector_start )
+		if (m_partition_new->sector_start < m_partition_original->sector_start)
 			action = MOVE_LEFT_GROW ;
 	}
-	else if ( partition_new->get_sector_length() < partition_original->get_sector_length() )
+	else if (m_partition_new->get_sector_length() < m_partition_original->get_sector_length())
 	{
 		//Shrink partition
 		action = SHRINK ;
-		if ( partition_new->sector_start > partition_original->sector_start )
+		if (m_partition_new->sector_start > m_partition_original->sector_start)
 			action = MOVE_RIGHT_SHRINK ;
-		if ( partition_new->sector_start < partition_original->sector_start )
+		if (m_partition_new->sector_start < m_partition_original->sector_start)
 			action = MOVE_LEFT_SHRINK ;
 	}
 	else
 	{
 		//No change in partition size
-		if ( partition_new->sector_start > partition_original->sector_start )
+		if (m_partition_new->sector_start > m_partition_original->sector_start)
 			action = MOVE_RIGHT ;
-		if ( partition_new->sector_start < partition_original->sector_start )
+		if (m_partition_new->sector_start < m_partition_original->sector_start)
 			action = MOVE_LEFT ;
 	}
 
 	switch ( action )
 	{
 		case NONE		:
-			description = Glib::ustring::compose( _("resize/move %1"), partition_original->get_path() );
-			description += " (" ;
-			description += _("new and old partition have the same size and position.  Hence continuing anyway") ;
-			description += ")" ;
+			m_description = Glib::ustring::compose(_("resize/move %1"), m_partition_original->get_path());
+			m_description += " (";
+			m_description += _("new and old partition have the same size and position.  Hence continuing anyway");
+			m_description += ")";
 			break ;
 		case MOVE_RIGHT		:
-			description = Glib::ustring::compose( _("Move %1 to the right"), partition_original->get_path() );
+			m_description = Glib::ustring::compose(_("Move %1 to the right"), m_partition_original->get_path());
 			break ;
 		case MOVE_LEFT		:
-			description = Glib::ustring::compose( _("Move %1 to the left"), partition_original->get_path() );
+			m_description = Glib::ustring::compose(_("Move %1 to the left"), m_partition_original->get_path());
 			break ;
 		case GROW 		:
-			description = _("Grow %1 from %2 to %3") ;
+			m_description = _("Grow %1 from %2 to %3");
 			break ;
 		case SHRINK		:
-			description = _("Shrink %1 from %2 to %3") ;
+			m_description = _("Shrink %1 from %2 to %3");
 			break ;
 		case MOVE_RIGHT_GROW	:
-			description = _("Move %1 to the right and grow it from %2 to %3") ;
+			m_description = _("Move %1 to the right and grow it from %2 to %3");
 			break ;
 		case MOVE_RIGHT_SHRINK	:
-			description = _("Move %1 to the right and shrink it from %2 to %3") ;
+			m_description = _("Move %1 to the right and shrink it from %2 to %3");
 			break ;
 		case MOVE_LEFT_GROW	:
-			description = _("Move %1 to the left and grow it from %2 to %3") ;
+			m_description = _("Move %1 to the left and grow it from %2 to %3");
 			break ;
 		case MOVE_LEFT_SHRINK	:
-			description = _("Move %1 to the left and shrink it from %2 to %3") ;
+			m_description = _("Move %1 to the left and shrink it from %2 to %3");
 			break ;
 	}
 
-	if ( ! description .empty() && action != NONE && action != MOVE_LEFT && action != MOVE_RIGHT )
-		description = Glib::ustring::compose( description,
-		                                partition_original->get_path(),
-		                                Utils::format_size( partition_original->get_sector_length(),
-		                                                    partition_original->sector_size ),
-		                                Utils::format_size( partition_new->get_sector_length(),
-		                                                    partition_new->sector_size ) );
+	if (! m_description.empty() && action != NONE && action != MOVE_LEFT && action != MOVE_RIGHT)
+	{
+		m_description = Glib::ustring::compose(m_description,
+		                                m_partition_original->get_path(),
+		                                Utils::format_size(m_partition_original->get_sector_length(),
+		                                                   m_partition_original->sector_size),
+		                                Utils::format_size(m_partition_new->get_sector_length(),
+		                                                   m_partition_new->sector_size));
+	}
 }
 
+
 void OperationResizeMove::apply_normal_to_visual( PartitionVector & partitions )
 {
-	g_assert( partition_original != NULL );  // Bug: Not initialised by constructor or reset later
-	g_assert( partition_new != NULL );  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_original != nullptr);  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_new != nullptr);  // Bug: Not initialised by constructor or reset later
 
 	int index_extended;
 	int index;
 
-	if ( partition_original->inside_extended )
+	if (m_partition_original->inside_extended)
 	{
 		index_extended = find_extended_partition( partitions );
 		if ( index_extended >= 0 )
@@ -158,14 +161,14 @@ void OperationResizeMove::apply_normal_to_visual( PartitionVector & partitions )
 
 			if ( index >= 0 )
 			{
-				partitions[index_extended].logicals.replace_at( index, partition_new );
+				partitions[index_extended].logicals.replace_at(index, m_partition_new.get());
 				remove_adjacent_unallocated( partitions[index_extended].logicals, index );
 
-				insert_unallocated( partitions[index_extended].logicals,
-				                    partitions[index_extended].sector_start,
-				                    partitions[index_extended].sector_end,
-				                    device.sector_size,
-				                    true );
+				insert_unallocated(partitions[index_extended].logicals,
+				                   partitions[index_extended].sector_start,
+				                   partitions[index_extended].sector_end,
+				                   m_device.sector_size,
+				                   true);
 			}
 		}
 	}
@@ -175,17 +178,18 @@ void OperationResizeMove::apply_normal_to_visual( PartitionVector & partitions )
 
 		if ( index >= 0 )
 		{
-			partitions.replace_at( index, partition_new );
+			partitions.replace_at(index, m_partition_new.get());
 			remove_adjacent_unallocated( partitions, index ) ;
 
-			insert_unallocated( partitions, 0, device .length -1, device .sector_size, false ) ;
+			insert_unallocated(partitions, 0, m_device.length -1, m_device.sector_size, false);
 		}
 	}
 }
 
+
 void OperationResizeMove::apply_extended_to_visual( PartitionVector & partitions )
 {
-	g_assert( partition_new != NULL );  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_new != nullptr);  // Bug: Not initialised by constructor or reset later
 
 	int index_extended;
 
@@ -198,13 +202,13 @@ void OperationResizeMove::apply_extended_to_visual( PartitionVector & partitions
 		index_extended = find_extended_partition( partitions );
 		if ( index_extended >= 0 )
 		{
-			partitions[index_extended].sector_start = partition_new->sector_start;
-			partitions[index_extended].sector_end   = partition_new->sector_end;
+			partitions[index_extended].sector_start = m_partition_new->sector_start;
+			partitions[index_extended].sector_end   = m_partition_new->sector_end;
 		}
-	
-		insert_unallocated( partitions, 0, device .length -1, device .sector_size, false ) ;
+
+		insert_unallocated(partitions, 0, m_device.length -1, m_device.sector_size, false);
 	}
-	
+
 	//stuff INSIDE extended partition
 	index_extended = find_extended_partition( partitions );
 	if ( index_extended >= 0 )
@@ -217,14 +221,15 @@ void OperationResizeMove::apply_extended_to_visual( PartitionVector & partitions
 		     partitions[index_extended].logicals.back().type == TYPE_UNALLOCATED )
 			partitions[ index_extended ] .logicals .pop_back() ;
 	
-		insert_unallocated( partitions[ index_extended ] .logicals,
-				    partitions[ index_extended ] .sector_start,
-				    partitions[ index_extended ] .sector_end,
-				    device .sector_size,
-				    true ) ;
+		insert_unallocated(partitions[index_extended].logicals,
+				   partitions[index_extended].sector_start,
+				   partitions[index_extended].sector_end,
+				   m_device.sector_size,
+				   true);
 	}
 }
 
+
 void OperationResizeMove::remove_adjacent_unallocated( PartitionVector & partitions, int index_orig )
 {
 	//remove unallocated space following the original partition
@@ -237,15 +242,15 @@ void OperationResizeMove::remove_adjacent_unallocated( PartitionVector & partiti
 		partitions .erase( partitions .begin() + ( index_orig -1 ) ) ;
 }
 
+
 bool OperationResizeMove::merge_operations( const Operation & candidate )
 {
-	g_assert( partition_new != NULL );  // Bug: Not initialised by constructor or reset later
+	g_assert(m_partition_new != nullptr);  // Bug: Not initialised by constructor or reset later
 
-	if ( candidate.type == OPERATION_RESIZE_MOVE              &&
-	     *partition_new == candidate.get_partition_original()    )
+	if (candidate.m_type == OPERATION_RESIZE_MOVE              &&
+	    *m_partition_new == candidate.get_partition_original()   )
 	{
-		delete partition_new;
-		partition_new = candidate.get_partition_new().clone();
+		m_partition_new.reset(candidate.get_partition_new().clone());
 		create_description();
 		return true;
 	}
@@ -253,4 +258,5 @@ bool OperationResizeMove::merge_operations( const Operation & candidate )
 	return false;
 }
 
-} //GParted
+
+}  // namespace GParted
