@@ -17,9 +17,17 @@
 
 #include "Partition.h"
 
+#include "Utils.h"
+
+#include <algorithm>
+#include <vector>
+#include <glibmm/ustring.h>
+
+
 namespace GParted
 {
 
+
 Partition::Partition()
 {
 	Reset() ;
@@ -54,10 +62,11 @@ void Partition::Reset()
 	inside_extended = busy = strict_start = false ;
 	fs_readonly = false;
 	logicals .clear() ;
-	flags .clear() ;
+	m_flags.clear();
 	mountpoints .clear() ;
 }
 
+
 void Partition::Set( const Glib::ustring & device_path,
                      const Glib::ustring & partition,
                      int partition_number,
@@ -260,7 +269,8 @@ Sector Partition::get_sector_length() const
 		return -1 ;
 }
 
-Glib::ustring Partition::get_path() const
+
+const Glib::ustring& Partition::get_path() const
 {
 	return path;
 }
@@ -270,20 +280,66 @@ bool Partition::filesystem_label_known() const
 	return have_filesystem_label;
 }
 
+
 //Return the file system label or "" if unknown.
-Glib::ustring Partition::get_filesystem_label() const
+const Glib::ustring& Partition::get_filesystem_label() const
 {
 	if ( have_filesystem_label )
 		return filesystem_label;
-	return "";
+
+	static Glib::ustring unknown_label;
+	return unknown_label;
 }
 
+
 void Partition::set_filesystem_label( const Glib::ustring & filesystem_label )
 {
 	this->filesystem_label = filesystem_label;
 	have_filesystem_label = true;
 }
 
+
+bool Partition::is_flag_set(const Glib::ustring& flag) const
+{
+	for (unsigned int i = 0; i < m_flags.size(); i++)
+		if (m_flags[i] == flag)
+			return true;
+	return false;
+}
+
+
+void Partition::set_only_flag(const Glib::ustring& flag)
+{
+	m_flags.clear();
+	m_flags.push_back(flag);
+}
+
+
+void Partition::set_flag(const Glib::ustring& flag)
+{
+	if (! is_flag_set(flag))
+		m_flags.push_back(flag);
+}
+
+
+void Partition::clear_all_flags()
+{
+	m_flags.clear();
+}
+
+
+const std::vector<Glib::ustring>& Partition::get_flags() const
+{
+	return m_flags;
+}
+
+
+void Partition::set_flags(const std::vector<Glib::ustring>& flags)
+{
+	m_flags = flags;
+}
+
+
 bool Partition::operator==( const Partition & partition ) const
 {
 	return device_path == partition .device_path &&
@@ -359,15 +415,18 @@ void Partition::add_mountpoints( const std::vector<Glib::ustring> & mountpoints
 	this ->mountpoints .insert( this ->mountpoints .end(), mountpoints .begin(), mountpoints .end() ) ;
 }
 
-Glib::ustring Partition::get_mountpoint() const 
+
+const Glib::ustring& Partition::get_mountpoint() const
 {
 	if ( mountpoints .size() > 0 )
 		return mountpoints .front() ;
 
-	return "" ;
+	static Glib::ustring unknown_mountpoint;
+	return unknown_mountpoint;
 }
 
-std::vector<Glib::ustring> Partition::get_mountpoints() const 
+
+const std::vector<Glib::ustring>& Partition::get_mountpoints() const
 {
 	return mountpoints ;
 }
@@ -492,8 +551,5 @@ Sector Partition::calc_significant_unallocated_sectors() const
 	return significant ;
 }
 
-Partition::~Partition()
-{
-}
 
-} //GParted
+}  // namespace GParted
