@@ -40,6 +40,8 @@ FS exfat::get_filesystem_support()
 	if (! Glib::find_program_in_path("dump.exfat").empty())
 		fs.read = FS::EXTERNAL;
 
+	Glib::ustring output;
+	Glib::ustring error;
 	if (! Glib::find_program_in_path("mkfs.exfat").empty())
 	{
 		Utils::execute_command("mkfs.exfat -V", output, error, true);
@@ -75,6 +77,8 @@ FS exfat::get_filesystem_support()
 
 void exfat::set_used_sectors(Partition& partition)
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	Utils::execute_command("dump.exfat " + Glib::shell_quote(partition.get_path()), output, error, true);
 	// dump.exfat returns non-zero status for both success and failure.  Instead use
 	// non-empty stderr to identify failure.
@@ -163,9 +167,10 @@ void exfat::set_used_sectors(Partition& partition)
 
 bool exfat::create(const Partition& new_partition, OperationDetail& operationdetail)
 {
-	return ! execute_command("mkfs.exfat -L " + Glib::shell_quote(new_partition.get_filesystem_label()) +
-	                         " " + Glib::shell_quote(new_partition.get_path()),
-	                         operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
+	return ! operationdetail.execute_command("mkfs.exfat -L " +
+	                        Glib::shell_quote(new_partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(new_partition.get_path()),
+	                        EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
 }
 
 
@@ -175,8 +180,10 @@ void exfat::read_label(Partition& partition)
 		// Running tune.exfat on a mounted file system fails so don't try.
 		return;
 
-	exit_status = Utils::execute_command("tune.exfat -l " + Glib::shell_quote(partition.get_path()),
-	                                     output, error, true);
+	Glib::ustring output;
+	Glib::ustring error;
+	int exit_status = Utils::execute_command("tune.exfat -l " + Glib::shell_quote(partition.get_path()),
+	                        output, error, true);
 	if (exit_status != 0)
 	{
 		if (! output.empty())
@@ -192,9 +199,10 @@ void exfat::read_label(Partition& partition)
 
 bool exfat::write_label(const Partition& partition, OperationDetail& operationdetail)
 {
-	return ! execute_command("tune.exfat -L " + Glib::shell_quote(partition.get_filesystem_label()) +
-	                         " " + Glib::shell_quote(partition.get_path()),
-	                         operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
+	return ! operationdetail.execute_command("tune.exfat -L " +
+	                        Glib::shell_quote(partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
 }
 
 
@@ -204,8 +212,10 @@ void exfat::read_uuid(Partition& partition)
 		// Running tune.exfat on a mounted file system fails so don't try.
 		return;
 
-	exit_status = Utils::execute_command("tune.exfat -i " + Glib::shell_quote(partition.get_path()),
-	                                     output, error, true);
+	Glib::ustring output;
+	Glib::ustring error;
+	int exit_status = Utils::execute_command("tune.exfat -i " + Glib::shell_quote(partition.get_path()),
+	                        output, error, true);
 	if (exit_status != 0)
 	{
 		if (! output.empty())
@@ -222,15 +232,16 @@ void exfat::read_uuid(Partition& partition)
 
 bool exfat::write_uuid(const Partition& partition, OperationDetail& operationdetail)
 {
-	return ! execute_command("tune.exfat -I " + random_serial() + " " + Glib::shell_quote(partition.get_path()),
-	                         operationdetail, EXEC_CHECK_STATUS);
+	return ! operationdetail.execute_command("tune.exfat -I " + random_serial() + " " +
+	                        Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
 
 bool exfat::check_repair(const Partition& partition, OperationDetail& operationdetail)
 {
-	return ! execute_command("fsck.exfat -y -v " + Glib::shell_quote(partition.get_path()),
-	                         operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
+	return ! operationdetail.execute_command("fsck.exfat -y -v " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
 }
 
 
@@ -262,4 +273,4 @@ Glib::ustring exfat::random_serial()
 }
 
 
-} //GParted
+}  // namespace GParted
