@@ -25,6 +25,7 @@
 namespace GParted
 {
 
+
 FS f2fs::get_filesystem_support()
 {
 	FS fs( FS_F2FS );
@@ -56,8 +57,10 @@ FS f2fs::get_filesystem_support()
 
 void f2fs::set_used_sectors(Partition & partition)
 {
-	exit_status = Utils::execute_command("dump.f2fs -d 1 " + Glib::shell_quote(partition.get_path()),
-	                                     output, error, true);
+	Glib::ustring output;
+	Glib::ustring error;
+	int exit_status = Utils::execute_command("dump.f2fs -d 1 " + Glib::shell_quote(partition.get_path()),
+	                        output, error, true);
 	if (exit_status != 0)
 	{
 		if (! output.empty())
@@ -120,9 +123,10 @@ void f2fs::set_used_sectors(Partition & partition)
 
 bool f2fs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkfs.f2fs -l " + Glib::shell_quote( new_partition.get_filesystem_label() ) +
-	                          " " + Glib::shell_quote( new_partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("mkfs.f2fs -l " +
+	                        Glib::shell_quote(new_partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(new_partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
 
@@ -134,16 +138,16 @@ bool f2fs::resize(const Partition & partition_new, OperationDetail & operationde
 		// system is currently stored on.
 		size = "-t " + Utils::num_to_str(partition_new.get_sector_length()) + " ";
 
-	return ! execute_command("resize.f2fs " + size + Glib::shell_quote(partition_new.get_path()),
-	                         operationdetail, EXEC_CHECK_STATUS);
+	return ! operationdetail.execute_command("resize.f2fs " + size + Glib::shell_quote(partition_new.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
 
 bool f2fs::check_repair(const Partition & partition, OperationDetail & operationdetail)
 {
-	return ! execute_command("fsck.f2fs -f -a " + Glib::shell_quote(partition.get_path()),
-	                         operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
+	return ! operationdetail.execute_command("fsck.f2fs -f -a " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
 }
 
 
-} //GParted
+}  // namespace GParted
