@@ -26,6 +26,7 @@
 namespace GParted
 {
 
+
 FS hfs::get_filesystem_support()
 {
 	FS fs( FS_HFS );
@@ -47,7 +48,7 @@ FS hfs::get_filesystem_support()
 	fs.move = FS::GPARTED;
 	fs .online_read = FS::GPARTED ;
 
-	fs_limits.max_size = 2048 * MEBIBYTE;
+	m_fs_limits.max_size = 2048 * MEBIBYTE;
 
 	return fs ;
 }
@@ -60,14 +61,16 @@ bool hfs::create( const Partition & new_partition, OperationDetail & operationde
 	else
 		cmd = "hformat -l " + Glib::shell_quote( new_partition.get_filesystem_label() ) +
 		      " " + Glib::shell_quote( new_partition.get_path() );
-	return ! execute_command( cmd , operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command(cmd, EXEC_CHECK_STATUS);
 }
 
+
 bool hfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
 	//FIXME: find out what the returnvalue is in case of modified.. also check what the -a flag does.. (there is no manpage)
-	return ! execute_command( "hfsck -v " + Glib::shell_quote( partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("hfsck -v " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
-} //GParted
+
+}  // namespace GParted
