@@ -27,6 +27,7 @@
 namespace GParted
 {
 
+
 const Glib::ustring & luks::get_custom_text( CUSTOM_TEXT ttype, int index ) const
 {
 	/* TO TRANSLATORS: these labels will be used in the partition menu */
@@ -67,13 +68,11 @@ FS luks::get_filesystem_support()
 		// the kernel, which it doesn't need.
 		fs.grow = FS::EXTERNAL;
 
-#ifdef ENABLE_ONLINE_RESIZE
 		if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
 		{
 			fs.online_grow   = FS::EXTERNAL;
 			fs.online_shrink = FS::EXTERNAL;
 		}
-#endif
 	}
 
 	return fs;
@@ -151,7 +150,7 @@ bool luks::resize( const Partition & partition_new, OperationDetail & operationd
 		}
 	}
 
-	Glib::ustring size = "";
+	Glib::ustring size;
 	if ( ! fill_partition )
 		// Cryptsetup resize takes the size of the encryption mapping, not the
 		// size of the underlying block device.  Both device-mapper and cryptsetup
@@ -163,8 +162,9 @@ bool luks::resize( const Partition & partition_new, OperationDetail & operationd
 	if (mapping.key_loc == KEYLOC_KeyRing)
 		pw = PasswordRAMStore::lookup(partition_new.uuid);
 
-	return ! execute_command("cryptsetup -v " + size + "resize " + Glib::shell_quote(mapping.name),
-	                         pw, operationdetail, EXEC_CHECK_STATUS);
+	return ! operationdetail.execute_command("cryptsetup -v " + size + "resize " + Glib::shell_quote(mapping.name),
+	                        pw, EXEC_CHECK_STATUS);
 }
 
-} //GParted
+
+}  // namespace GParted
