@@ -25,6 +25,7 @@
 namespace GParted
 {
 
+
 FS nilfs2::get_filesystem_support()
 {
 	FS fs( FS_NILFS2 );
@@ -62,16 +63,14 @@ FS nilfs2::get_filesystem_support()
 	fs.copy = FS::GPARTED;
 	fs.move = FS::GPARTED;
 	fs .online_read = FS::GPARTED ;
-#ifdef ENABLE_ONLINE_RESIZE
 	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
 	{
 		fs .online_grow = fs .grow ;
 		fs .online_shrink = fs .shrink ;
 	}
-#endif
 
-	//Minimum FS size is 128M+4K using mkfs.nilfs2 defaults
-	fs_limits.min_size = 128 * MEBIBYTE + 4 * KIBIBYTE;
+	// Minimum FS size is 128M+4K using mkfs.nilfs2 defaults
+	m_fs_limits.min_size = 128 * MEBIBYTE + 4 * KIBIBYTE;
 
 	return fs ;
 }
@@ -79,8 +78,10 @@ FS nilfs2::get_filesystem_support()
 
 void nilfs2::set_used_sectors(Partition& partition)
 {
-	exit_status = Utils::execute_command("nilfs-tune -l " + Glib::shell_quote(partition.get_path()),
-	                                     output, error, true);
+	Glib::ustring output;
+	Glib::ustring error;
+	int exit_status = Utils::execute_command("nilfs-tune -l " + Glib::shell_quote(partition.get_path()),
+	                        output, error, true);
 	if (exit_status != 0)
 	{
 		if (! output.empty())
@@ -119,6 +120,8 @@ void nilfs2::set_used_sectors(Partition& partition)
 
 void nilfs2::read_label( Partition & partition )
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	if ( ! Utils::execute_command( "nilfs-tune -l " + Glib::shell_quote( partition.get_path() ),
 	                               output, error, true )                                         )
 	{
@@ -138,15 +141,20 @@ void nilfs2::read_label( Partition & partition )
 	}
 }
 
+
 bool nilfs2::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "nilfs-tune -L " + Glib::shell_quote( partition.get_filesystem_label() ) +
-	                          " " + Glib::shell_quote( partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("nilfs-tune -L " +
+	                        Glib::shell_quote(partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 void nilfs2::read_uuid( Partition & partition )
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	if ( ! Utils::execute_command( "nilfs-tune -l " + Glib::shell_quote( partition.get_path() ),
 	                               output, error, true )                                         )
 	{
@@ -162,24 +170,28 @@ void nilfs2::read_uuid( Partition & partition )
 	}
 }
 
+
 bool nilfs2::write_uuid( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "nilfs-tune -U " + Glib::shell_quote( Utils::generate_uuid() ) +
-	                          " " + Glib::shell_quote( partition .get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("nilfs-tune -U " + Glib::shell_quote(Utils::generate_uuid()) +
+	                        " " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 bool nilfs2::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkfs.nilfs2 -L " + Glib::shell_quote( new_partition.get_filesystem_label() ) +
-	                          " " + Glib::shell_quote( new_partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("mkfs.nilfs2 -L " +
+	                        Glib::shell_quote(new_partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(new_partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 bool nilfs2::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	bool success = true ;
-
+	int exit_status = 0;
 	Glib::ustring mount_point ;
 	if ( ! partition_new .busy )
 	{
@@ -187,9 +199,12 @@ bool nilfs2::resize( const Partition & partition_new, OperationDetail & operatio
 		if ( mount_point .empty() )
 			return false ;
 
-		success &= ! execute_command( "mount -v -t nilfs2 " + Glib::shell_quote( partition_new.get_path() ) +
-		                              " " + Glib::shell_quote( mount_point ),
-		                              operationdetail, EXEC_CHECK_STATUS );
+		exit_status = operationdetail.execute_command("mount -v -t nilfs2 " +
+		                        Glib::shell_quote(partition_new.get_path()) +
+		                        " " + Glib::shell_quote(mount_point),
+		                        EXEC_CHECK_STATUS);
+		if (exit_status != 0)
+			success = false;
 	}
 
 	if ( success )
@@ -197,12 +212,19 @@ bool nilfs2::resize( const Partition & partition_new, OperationDetail & operatio
 		Glib::ustring size;
 		if ( ! fill_partition )
 			size = " " + Utils::num_to_str(partition_new.get_byte_length() / KIBIBYTE) + "K";
-		success &= ! execute_command("nilfs-resize -v -y " + Glib::shell_quote(partition_new.get_path()) + size,
-		                             operationdetail, EXEC_CHECK_STATUS);
+		exit_status = operationdetail.execute_command("nilfs-resize -v -y " +
+		                        Glib::shell_quote(partition_new.get_path()) + size,
+		                        EXEC_CHECK_STATUS);
+		if (exit_status != 0)
+			success = false;
 
 		if ( ! partition_new. busy )
-			success &= ! execute_command( "umount -v " + Glib::shell_quote( mount_point ),
-			                              operationdetail, EXEC_CHECK_STATUS );
+		{
+			exit_status = operationdetail.execute_command("umount -v " + Glib::shell_quote(mount_point),
+			                        EXEC_CHECK_STATUS);
+			if (exit_status != 0)
+				success = false;
+		}
 	}
 
 	if ( ! partition_new .busy )
@@ -211,4 +233,5 @@ bool nilfs2::resize( const Partition & partition_new, OperationDetail & operatio
 	return success ;
 }
 
-} //GParted
+
+}  // namespace GParted
