@@ -26,6 +26,7 @@
 namespace GParted
 {
 
+
 FS reiserfs::get_filesystem_support()
 {
 	FS fs( FS_REISERFS );
@@ -73,8 +74,8 @@ FS reiserfs::get_filesystem_support()
 	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
 		fs. online_grow = fs. grow ;
 
-	//Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
-	fs_limits.min_size = 34 * MEBIBYTE;
+	// Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
+	m_fs_limits.min_size = 34 * MEBIBYTE;
 
 	return fs ;
 }
@@ -82,8 +83,10 @@ FS reiserfs::get_filesystem_support()
 
 void reiserfs::set_used_sectors(Partition& partition)
 {
-	exit_status = Utils::execute_command("debugreiserfs " + Glib::shell_quote(partition.get_path()),
-	                                     output, error, true);
+	Glib::ustring output;
+	Glib::ustring error;
+	int exit_status = Utils::execute_command("debugreiserfs " + Glib::shell_quote(partition.get_path()),
+	                        output, error, true);
 	if (exit_status != 0)
 	{
 		if (! output.empty())
@@ -120,6 +123,8 @@ void reiserfs::set_used_sectors(Partition& partition)
 
 void reiserfs::read_label( Partition & partition )
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	if ( ! Utils::execute_command( "debugreiserfs " + Glib::shell_quote( partition.get_path() ),
 	                               output, error, true )                                         )
 	{
@@ -135,15 +140,20 @@ void reiserfs::read_label( Partition & partition )
 	}
 }
 	
+
 bool reiserfs::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "reiserfstune --label " + Glib::shell_quote( partition.get_filesystem_label() ) +
-	                          " " + Glib::shell_quote( partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("reiserfstune --label " +
+	                        Glib::shell_quote(partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 void reiserfs::read_uuid( Partition & partition )
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	if ( ! Utils::execute_command( "debugreiserfs " + Glib::shell_quote( partition .get_path() ), output, error, true ) )
 	{
 		partition .uuid = Utils::regexp_label( output, "^UUID:[[:blank:]]*(" RFC4122_NONE_NIL_UUID_REGEXP ")" ) ;
@@ -158,20 +168,23 @@ void reiserfs::read_uuid( Partition & partition )
 	}
 }
 
+
 bool reiserfs::write_uuid( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "reiserfstune -u random " + Glib::shell_quote( partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("reiserfstune -u random " + Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 bool reiserfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkreiserfs -f -f --label " +
-	                          Glib::shell_quote( new_partition.get_filesystem_label() ) +
-	                          " " + Glib::shell_quote( new_partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
+	return ! operationdetail.execute_command("mkreiserfs -f -f --label " +
+	                        Glib::shell_quote(new_partition.get_filesystem_label()) +
+	                        " " + Glib::shell_quote(new_partition.get_path()),
+	                        EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
 }
 
+
 bool reiserfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 { 
 	Glib::ustring size;
@@ -179,25 +192,33 @@ bool reiserfs::resize( const Partition & partition_new, OperationDetail & operat
 		size = " -s " + Utils::num_to_str(partition_new.get_byte_length());
 	const Glib::ustring resize_cmd = "echo y | resize_reiserfs" + size +
 	                                 " " + Glib::shell_quote( partition_new.get_path() );
-	exit_status = execute_command( "sh -c " + Glib::shell_quote( resize_cmd ), operationdetail );
+	int exit_status = operationdetail.execute_command("sh -c " + Glib::shell_quote(resize_cmd));
 	// NOTE: Neither resize_reiserfs manual page nor the following commit, which first
 	// added this check, indicate why exit status 1 also indicates success.  Commit
 	// from 2006-05-23:
 	//     7bb7e8a84f164cd913384509a6adc3739a9d8b78
 	//     Use ped_device_read and ped_device_write instead of 'dd' to copy
 	bool success = ( exit_status == 0 || exit_status == 1 );
-	set_status( operationdetail, success );
+	operationdetail.get_last_child().set_success_and_capture_errors(success);
 	return success;
 }
 
+
 bool reiserfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	exit_status = execute_command( "reiserfsck --yes --fix-fixable --quiet " +
-	                               Glib::shell_quote( partition.get_path() ),
-	                               operationdetail, EXEC_CANCEL_SAFE );
-	bool success = ( exit_status == 0 || exit_status == 1 );
-	set_status( operationdetail, success );
+	int exit_status = operationdetail.execute_command("reiserfsck --yes --fix-fixable --quiet " +
+	                        Glib::shell_quote(partition.get_path()),
+	                        EXEC_CANCEL_SAFE);
+	// From reiserfsck(8) manual page:
+	//     EXIT CODES
+	//         reiserfsck uses the following exit codes:
+	//             0  - No errors.
+	//             1  - File system errors corrected.
+	//             2  - Reboot is needed.
+	bool success = (exit_status == 0 || exit_status == 1);
+	operationdetail.get_last_child().set_success_and_capture_errors(success);
 	return success;
 }
 
-} //GParted
+
+}  // namespace GParted
