@@ -29,6 +29,7 @@
 namespace GParted
 {
 
+
 const Byte_Value MIN_UDF_BLOCKS = 300;
 const Byte_Value MAX_UDF_BLOCKS = (1LL << 32) - 1;
 
@@ -47,6 +48,8 @@ FS udf::get_filesystem_support()
 		fs.create_with_label = FS::EXTERNAL;
 
 		// Detect old mkudffs prior to version 1.1 by lack of --label option.
+		Glib::ustring output;
+		Glib::ustring error;
 		Utils::execute_command( "mkudffs --help", output, error, true );
 		m_old_mkudffs = Utils::regexp_label(output + error, "--label").empty();
 	}
@@ -79,8 +82,10 @@ FS_Limits udf::get_filesystem_limits( const Partition & partition ) const
 
 void udf::set_used_sectors( Partition & partition )
 {
-	exit_status = Utils::execute_command( "udfinfo --utf8 " + Glib::shell_quote( partition.get_path() ),
-	                                      output, error, true );
+	Glib::ustring output;
+	Glib::ustring error;
+	int exit_status = Utils::execute_command("udfinfo --utf8 " + Glib::shell_quote(partition.get_path()),
+	                        output, error, true);
 	if ( exit_status != 0 )
 	{
 		if ( ! output.empty() )
@@ -130,6 +135,8 @@ void udf::set_used_sectors( Partition & partition )
 
 void udf::read_label( Partition & partition )
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	if ( ! Utils::execute_command( "udflabel --utf8 " + Glib::shell_quote( partition.get_path() ),
 	                               output, error, true )                                           )
 	{
@@ -145,15 +152,19 @@ void udf::read_label( Partition & partition )
 	}
 }
 
+
 bool udf::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "udflabel --utf8 " + Glib::shell_quote( partition.get_path() ) +
-	                          " " + Glib::shell_quote( partition.get_filesystem_label() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("udflabel --utf8 " + Glib::shell_quote(partition.get_path()) +
+	                        " " + Glib::shell_quote(partition.get_filesystem_label()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 void udf::read_uuid( Partition & partition )
 {
+	Glib::ustring output;
+	Glib::ustring error;
 	if ( ! Utils::execute_command( "udfinfo --utf8 " + Glib::shell_quote( partition.get_path() ),
 	                               output, error, true )                                          )
 	{
@@ -169,12 +180,15 @@ void udf::read_uuid( Partition & partition )
 	}
 }
 
+
 bool udf::write_uuid( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "udflabel --utf8 --uuid=random " + Glib::shell_quote( partition.get_path() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	return ! operationdetail.execute_command("udflabel --utf8 --uuid=random " +
+	                        Glib::shell_quote(partition.get_path()),
+	                        EXEC_CHECK_STATUS);
 }
 
+
 bool udf::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	// NOTE: mkudffs from udftools prior to version 1.1 does not check for partition
@@ -246,12 +260,12 @@ bool udf::create( const Partition & new_partition, OperationDetail & operationde
 
 	// TODO: Add GUI option for choosing different optical disks and UDF revision.
 	// For now format as UDF revision 2.01 for hard disk media type.
-	return ! execute_command( "mkudffs --utf8 --media-type=hd --udfrev=0x201 " +
-	                          blocksize_args + label_args + Glib::shell_quote( new_partition.get_path() ),
-	                          operationdetail,
-	                          EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
+	return ! operationdetail.execute_command("mkudffs --utf8 --media-type=hd --udfrev=0x201 " +
+	                        blocksize_args + label_args + Glib::shell_quote(new_partition.get_path()),
+	                        EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE);
 }
 
+
 // Private methods
 
 // Return true only if all the characters in the string are ASCII (<= 0x7F), otherwise false.
@@ -278,4 +292,5 @@ size_t udf::find_first_non_latin1( const Glib::ustring & str )
 	return Glib::ustring::npos;
 }
 
-} //GParted
+
+}  // namespace GParted
